	SUBROUTINE rxns(ncomp,nvrxndata,j,i,k,y,dydt,
     &         poros,rhob,reta,rc,nlay,nrow,ncol,vrc)
c ***** Block 1: Comments block *******
c23456789012345678901234567890123456789012345678901234567890123456789012
c ncomp - Total number of components
c nvrxndata - Total number of variable reaction parameters to be input via RCT file
c J, I, K - node location (used if reaction parameters are spatially variable)
c y - Concentration value of all component at the node [array variable y(ncomp)]
c dydt - Computed RHS of your differential equation [array variable dydt(ncomp)]
c poros - porosity of the node
c reta -  Retardation factor [array variable reta(mcomp)]
c rhob -  bulk density of the node
c rc - Stores spatially constant reaction parameters (up to 100 values)
c nlay, nrow, ncol - Grid size (used only for dimensioning purposes)
c vrc - Array variable that stores spatially variable reaction parameters
c ***** End of Block 1 *******

c *** Block 2: Please do not modify this standard interface block ***
      !MS$ATTRIBUTES DLLEXPORT :: rxns
      IMPLICIT NONE
      INTEGER ncol,nrow,nlay
      INTEGER ncomp,nvrxndata,j,i,k
      INTEGER First_time
      DATA First_time/1/
      DOUBLE PRECISION y,dydt,poros,rhob,reta
      DOUBLE PRECISION rc,vrc
      DIMENSION y(ncomp),dydt(ncomp),rc(50)
      DIMENSION vrc(ncol,nrow,nlay,nvrxndata),reta(50)
C ****** End of block 2 *******

C *** Block 3: Declare your problem-specific new variables here ***
C     INTEGER
      DOUBLE PRECISION pce,tce,dce,vc,kpce,ktce,kdce,kvc 
      DOUBLE PRECISION ytcepce,ydcetce,yvcdce
C ***** End of Block 3  ******

C *** Block 4: Initilize reaction parameters here, if required ***
      IF (First_time .EQ. 1) THEN
         kpce = 0.005  !PCE first-order degradation rate
         ktce = 0.003  !TCE first-order degradation rate
         kdce = 0.002  !DCE first-order degradation rate
         kvc = 0.001  !VC first-order degradation rate
	 ytcepce = 131.36/165.8
	 ydcetce = 96.9/131.36
	 yvcdce = 62.45/96.9
         First_time = 0 !reset First_time to skip this block later
      END IF
C ***** End of Block 4  ******

C  *** Block 5: Definition of other variable names ***
       pce = y(1)
       tce = y(2)
       dce = y(3)
       vc = y(4)
C ***** End of Block 5  ******

c  *** Block 6: Definition of Differential Equations ***
       dydt(1) = -kpce*pce/reta(1)
       dydt(2) = (-ktce*tce + kpce*pce*ytcepce)/reta(2)
       dydt(3) = (-kdce*dce + ktce*tce*ydcetce)/reta(3) 
       dydt(4) = (-kvc*vc + kdce*dce*yvcdce)/reta(4)
C ***** End of Block 6  ******
      RETURN
      END

